# #!/usr/bin/env python
# # -*- coding: utf-8 -*-

from __future__ import annotations
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from SuPyMode.supermode import SuperMode

from typing import NoReturn
from SuPyMode.representation.base import InheritFromSuperMode, BaseSingleModePlot
import matplotlib.pyplot as plt


class Beta(InheritFromSuperMode, BaseSingleModePlot):
    """
    Represents the propagation constants (beta values) of a mode derived from a supermode in optical simulations.

    This class utilizes inheritance from `InheritFromSuperMode` for accessing supermode-related data and
    `BaseSingleModePlot` for plotting functionalities tailored to propagation constant visualization.

    Class Attributes:
        plot_style (dict): A dictionary defining the default style settings for plots generated by this class.

    Attributes:
        parent_supermode (InheritFromSuperMode): A reference to the parent supermode object from which beta data is sourced.
    """

    def __init__(self, parent_supermode: SuperMode):
        """
        Initializes a Beta object with a reference to a parent supermode.

        Args:
            parent_supermode (InheritFromSuperMode): The parent supermode object.
        """
        self.parent_supermode = parent_supermode
        self.data = self.parent_supermode.binding.get_betas()

    def _dress_ax(self, ax: plt.Axes) -> NoReturn:
        ax.set_xlabel('Inverse taper ratio')
        ax.set_ylabel('Propagation constant [rad/M]')


# -
